package com.ynet.life.base.logon;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.session.Session;
import com.ynet.gene.session.SessionManager;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.services.http.AsynchronousHttpService;

/* loaded from: com_ynet_life_base_logon.jar:com/ynet/life/base/logon/LifeLogonManager.class */
public class LifeLogonManager {
    private static final String SETTING_NAME_ENABLE_CONTROL = "enableLogonControl";
    private static final String SETTING_NAME_SERVER_ADDRESS = "serverAddress";
    private static final String SETTING_NAME_SIGNOFF_SERVLET = "signOffServlet";
    private static final String HTTP_HEAD = "http://";
    private static boolean IS_ENABLE_CONTROL = false;
    private static String SERVER_ADDRESS = "";
    private static String SIGNOFF_SERVLET = "";

    private LifeLogonManager() {
    }

    public static void initialize(LifeLogonEntryConfig config) throws TranFailException {
        LifeLogonEntry.initialize(config);
        boolean booleanValue = Boolean.valueOf(LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_ENABLE_CONTROL)).booleanValue();
        IS_ENABLE_CONTROL = booleanValue;
        if (booleanValue) {
            LifeLogonEntry.cleanTable();
        }
        SERVER_ADDRESS = LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_SERVER_ADDRESS);
        SIGNOFF_SERVLET = LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_SIGNOFF_SERVLET);
    }

    public static void addUser(Context conext, String sessionId, SessionManager sessionManager) throws TranFailException {
        if (IS_ENABLE_CONTROL) {
            LifeLogonEntry lastLogon = LifeLogonEntry.getCurrentUserLogonEntry(conext);
            String userId = lastLogon.getUserId();
            if (lastLogon.getSessionId() != null) {
                if (SERVER_ADDRESS.equals(lastLogon.getServerAddress())) {
                    Session lastSession = (Session) sessionManager.getSessions().get(lastLogon.getSessionId());
                    if (lastSession != null) {
                        try {
                            lastSession.setAttribute("sessionKickoutFlag", LifeConstants.FIELD_SUCC_FLAG_TRUE);
                        } catch (Exception unused) {
                        }
                    }
                } else {
                    String requestURL = HTTP_HEAD + lastLogon.getServerAddress() + SIGNOFF_SERVLET + "?" + GENEConstance.GENE_SESSION_ID_LABEL + "=" + lastLogon.getSessionId();
                    new AsynchronousHttpService(requestURL).start();
                }
                new LifeLogonEntry(userId, sessionId, SERVER_ADDRESS).update();
                return;
            }
            new LifeLogonEntry(userId, sessionId, SERVER_ADDRESS).addToDB();
        }
    }

    public static boolean isLogin(String bankId, String userId, SessionManager sessionManager) throws TranFailException {
        LifeLogonEntry lastLogon = LifeLogonEntry.getUserLogonEntry(userId);
        if (lastLogon.getSessionId() != null && SERVER_ADDRESS.equals(lastLogon.getServerAddress()) && ((Session) sessionManager.getSessions().get(lastLogon.getSessionId())) != null) {
            return true;
        }
        return false;
    }

    public static boolean isLogin(Context sessionContext, SessionManager sessionManager) throws TranFailException {
        LifeLogonEntry lastLogon = LifeLogonEntry.getCurrentUserLogonEntry(sessionContext);
        if (lastLogon.getSessionId() != null && SERVER_ADDRESS.equals(lastLogon.getServerAddress()) && ((Session) sessionManager.getSessions().get(lastLogon.getSessionId())) != null) {
            return true;
        }
        return false;
    }

    public static void setServerAddress(String serverAddress) {
        SERVER_ADDRESS = serverAddress;
    }

    public static String getServerAddress() {
        return SERVER_ADDRESS;
    }
}
